@echo off
goto 00_Start
###############################################################################

DEMO.BAT - demonstrate GREP software with the supplied sample files

To execute this demo, the sample files must be in the current directory.
Usage:
        DEMO
or:
        DEMO filename
If a filename is specified, the demo will run non-interactively and output will
be written to the named file. This is part of the actual regression tests.

The following environment variables get overwritten:
    B32 -- records whether the 32-bit program is being used in the demo
    G -- name of the program
    X -- used for scratch work

2001-12-22  author: Stan Brown, Oak Road Systems

                 Copyright 2001   Stan Brown, Oak Road Systems
                           http://oakroadsystems.com
###############################################################################
:00_Start
:: Check whether sufficient environment space is available.
set X=01234567890123456789012345678901234567890123456789
if "%X%" == "01234567890123456789012345678901234567890123456789" goto 01_EnvOK
set X=
echo.
echo This demo needs about 50 bytes of free environment space, but
echo less than that is available. Try running it in a secondary shell
echo and specifying environment space, like this:
echo           %%comspec%% /e:8192 /c %0
echo The figure of 8192 is just an example. Use a large enough number,
echo which depends on how much environment space you are already using.
echo If you have a SHELL statement in C:\CONFIG.SYS use that number
echo plus 50 or so; otherwise try /e:1024.
echo.
goto 99_Exit

:01_EnvOK
if "%2" == "" goto 02_ParamsOK
echo.
echo You invoked this batch file with two or more parameters. In
echo normal use it takes no parameters; the only optional parameter is
echo a file name for output.
echo.
goto 99_Exit
:02_ParamsOK

if not "%1" == "" goto 04_32or16
echo.
echo The demo can be run with 16-bit or 32-bit GREP. Some features are
echo available in 32-bit GREP but not 16-bit GREP. However, while
echo 16-bit GREP will run in any DOS session, 32-bit GREP requires a
echo command prompt under a version of Windows 95/98/ME/NT/2000/XP.
echo.
:04_32or16
set B32=no
choice /cny /n "Do you prefer the 32-bit demo? "
if errorlevel 2 set B32=yes
:: Now check that the executable program is actually available.
set G=grep16
if "%B32%" == "yes" set G=grep32
if exist %G%.exe goto 05_ExeFound
echo.
echo Please run this batch file from the same directory where the
echo '%G%.exe' program exists.
echo.
goto 99_Exit
:05_ExeFound
if "%1" == "" goto 90_Welcome
echo Output of "%0 %1" >%1
echo ====================================================================== >>%1
echo.>>%1
echo. | date >>%1
echo.>>%1
CTTY nul:
%G% -d- >>%1
CTTY con:
echo.>>%1
echo.>>%1
goto 99_BeginDemo
:90_Welcome
cls
echo Welcome to this demo of the GREP shareware program.
echo.
echo Please note: at present this demo focuses on recently added
echo features. Future versions of the demo may be more comprehensive.
echo.
echo The DOS program MORE.COM needs to be somewhere in your PATH. If
echo you have a normal DOS or WINDOWS installation, the MORE program
echo is already present in the right place.
echo.
echo NOTE: Every GREP command in this demo uses the /z option. That's
echo always a good idea in a batch file, so that any setting of the
echo environment variable is disregarded and the options in effect are
echo only those on the command line.
echo.
:99_BeginDemo

:: ============================================================================

if not "%1" == "" goto 201_BinaryOne
echo.
echo GREP can handle both text and binary files. 
echo.
choice /cyn /n "Would you like to see a demo of binary file searching? "
if errorlevel 2 goto 299_BinaryDone
cls
echo Suppose we want to find the word "warning" in the GREP executable, just
echo to see the warning messages. We'll use a regular expression [Ww]arning to
echo get both "warning" and "Warning". If we search in text mode, the special
echo characters in the %G%.exe make GREP miss some or all occurrences:
:201_BinaryOne
set X=[Ww]arning %G%.exe /BN
call demosub short %1
if not "%1" == "" goto 202_BinaryTwo
pause
echo.
echo But in binary mode, GREP will find all occurrences of the sought-after
echo string. We use /R3, not R2, because %G%.exe is a free-format binary file.
echo And we use /W40 to limit the buffers to 40 characters. (The sought-after
echo string is 7 characters long, so we'v met the requirement for /R3 that the
echo buffer should be at least double the string size.)
:202_BinaryTwo
set X=%X% /R3 /W40
call demosub long %1
if not "%1" == "" goto 203_BinaryThree
echo.
echo Note that the text characters are shown normally, and the binary characters
echo are shown as hexadecimal values.
echo.
echo The registered version of GREP can sense the file type. 
choice /cyn /n "Is this a registered copy? "
if errorlevel 2 goto 298_BinaryCleanup
cls
echo The /R-1 option tells GREP to look at each file and figure out whether it's
echo text or binary. When you show filename headers -- i.e., when you don't use 
echo the /H or /L or /U option -- GREP will tell you the type of each file.
echo.
echo Notice how GREP lets you specify different widths for text and binary
echo files. We want to allow a full line width for text files, but keep the
echo buffer fairly small for binary files.
echo.
:203_BinaryThree
set X=[Ww]arning /R-1 /W255,40 /N %G%.exe grepuser.htm
call demosub long %1
:298_BinaryCleanup
if "%1" == "" echo.
if "%1" == "" echo This concludes the demo of binary file features.
if "%1" == "" echo.
if "%1" == "" pause
if "%1" == "" goto 299_BinaryDone
echo.>> %1
echo This concludes the demo of binary file features.>> %1
echo.>> %1
:299_BinaryDone
if "%1" == "" cls

:: ============================================================================

if "%B32%" == "yes" goto 100_LocaleMaybe
if "%1" == "" echo.
if "%1" == "" echo Note: Locale demos are being skipped because they need 32-bit GREP.
if "%1" == "" echo.
if "%1" == "" goto 199_LocaleDone
echo. >>%1
echo Note: Locale demos are being skipped because they need 32-bit GREP. >>%1
echo. >>%1
goto 199_LocaleDone

:100_LocaleMaybe
if not "%1" == "" goto 101_Locale
echo.
echo The locale demos use supplied file TEST255, which contains 256
echo records of 21 characters each. Each record has the form
echo         X (code point  88)
echo         123456789012345678901
echo where X is the character as a character, " 88" is its ASCII value
echo in decimal, and CRLF is a carriage return/line feed. This is a
echo binary file and must be processed with the /R2 option.
echo.
choice /cny /n "Would you like to see the locale demos? "
if not errorlevel 2 goto 199_LocaleDone
cls
:101_Locale

if not "%1" == "" goto 110_DefaultLocaleB
echo.
echo By default, GREP operates in the "C" locale, in which characters
echo 128-255 don't have any meaning. For example, in the ISO-8859-1
echo character set, character 233 is the letter e with acute accent.
echo But in the default locale, it's not treated as a letter. Consider
echo the result of a case-blind search for that character:
:110_DefaultLocaleB
set X=/r2w21 \233 test255 /i
call demosub short %1

if not "%1" == "" goto 112_FrenchLocaleC
pause
echo.
echo Now try the same thing with the "fr" locale, which is suitable
echo for Western European languages. Now you also get character 201,
echo which in ISO-8859-1 is the capital E with acute accent. (The
echo characters may not look right, depending on how you have your DOS
echo set up.)
:112_FrenchLocaleC
set X=%X% /mfr
call demosub short %1
if not "%1" == "" goto 114_ExtLocaleD
echo Note a side effect of setting the locale. In the previous test,
echo character 233 is treated as unprintable. But the locale
echo determines which characters are treated as printable.
echo.
echo ......
echo.
echo Extended regexes (/E2 option) have character types and named
echo character classes, and these are sensitive to the locale setting.
echo For example, in the default "C" locale, only 32 characters are
echo considered punctuations. We can display them by using the
echo extended regex ^[[:punct:]], which asks for the beginning of line
echo (^) followed by a punctuation character:
:114_ExtLocaleE
set X=/r2 /w21 ^[[:punct:]] /e2 test255
call demosub long %1

if not "%1" == "" goto 115_ExtLocaleF
echo.
echo Now try that again with the "fr" locale. This time we get 85
echo punctuation characters:
:115_ExtLocaleF
set X=%X% /mfr
call demosub long %1

if not "%1" == "" goto 116_ExtLocaleG
echo.
echo It's clearer if we use the /C option to count matches, instead of
echo actually displaying them. This time let's count lower-case
echo letters with ^[[:lower:]], first in the default "C" locale and
echo then in the Western European "fr" locale:
:116_ExtLocaleG
set X=/r2 /w21 ^[[:lower:]] /e2 test255 /c
call demosub short %1
set X=%X% /mfr
call demosub short %1

if "%1" == "" echo.
if "%1" == "" echo This concludes the demo of locale features.
if "%1" == "" echo.
if "%1" == "" pause
if "%1" == "" goto 199_LocaleDone
echo.>> %1
echo This concludes the demo of locale features.>> %1
echo.>> %1
:199_LocaleDone
if "%1" == "" cls

echo.
echo Thank you for trying out this demo of the new features in GREP!
echo.
echo Please consult the user guide and reference manual for full description
echo of all the features of GREP. If you find it meets your needs, please
echo register on line at http://oakroadsystems.com/sharware or mail in the
echo form REGISTER.TXT or SITEREG.TXT with your payment. The registered
echo version of GREP has more features, like the ability to sense whether each
echo file is text or binary.
echo.

:99_Exit
set X=
set G=
set B32=
rem :: vim: ic tw=0 comments=n\:\:\:,n\:echo,n\:rem
